pub struct Boxed<T>(pub Box<T>);Tuple Fields
0: Box<T>Trait Implementations
Sourceimpl<T: ArgsInfo> ArgsInfo for Boxed<T>
impl<T: ArgsInfo> ArgsInfo for Boxed<T>
Sourcefn get_args_info() -> CommandInfoWithArgs
fn get_args_info() -> CommandInfoWithArgs
Returns the argument info.
Sourcefn get_subcommands() -> Vec<SubCommandInfo<'static>>
fn get_subcommands() -> Vec<SubCommandInfo<'static>>
Returns the list of subcommands
Sourceimpl<T: FromArgs> FromArgs for Boxed<T>
impl<T: FromArgs> FromArgs for Boxed<T>
Sourcefn from_args(command_name: &[&str], args: &[&str]) -> Result<Self, EarlyExit>
fn from_args(command_name: &[&str], args: &[&str]) -> Result<Self, EarlyExit>
Construct the type from an input set of arguments. Read more
Sourcefn redact_arg_values(
command_name: &[&str],
args: &[&str],
) -> Result<Vec<String>, EarlyExit>
fn redact_arg_values( command_name: &[&str], args: &[&str], ) -> Result<Vec<String>, EarlyExit>
Get a String with just the argument names, e.g., options, flags, subcommands, etc, but
without the values of the options and arguments. This can be useful as a means to capture
anonymous usage statistics without revealing the content entered by the end user. Read more
Sourceimpl<T: SubCommand> SubCommand for Boxed<T>
impl<T: SubCommand> SubCommand for Boxed<T>
Sourceconst COMMAND: &'static CommandInfo = T::COMMAND
const COMMAND: &'static CommandInfo = T::COMMAND
Information about the subcommand.
impl<T> StructuralPartialEq for Boxed<T>