pub struct CompositeCommand {
pub subcommand: CompositeSubcommand,
}Fields
subcommand: CompositeSubcommandTrait Implementations
Sourceimpl ArgsInfo for CompositeCommand
impl ArgsInfo for CompositeCommand
Sourcefn get_args_info() -> CommandInfoWithArgs
fn get_args_info() -> CommandInfoWithArgs
Returns the argument info.
Sourcefn get_subcommands() -> Vec<SubCommandInfo<'static>>
fn get_subcommands() -> Vec<SubCommandInfo<'static>>
Returns the list of subcommands
Sourceimpl Debug for CompositeCommand
impl Debug for CompositeCommand
Sourceimpl FromArgs for CompositeCommand
impl FromArgs for CompositeCommand
Sourcefn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
fn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
Construct the type from an input set of arguments. Read more
Sourcefn redact_arg_values(
__cmd_name: &[&str],
__args: &[&str],
) -> Result<Vec<String>, EarlyExit>
fn redact_arg_values( __cmd_name: &[&str], __args: &[&str], ) -> Result<Vec<String>, EarlyExit>
Get a String with just the argument names, e.g., options, flags, subcommands, etc, but
without the values of the options and arguments. This can be useful as a means to capture
anonymous usage statistics without revealing the content entered by the end user. Read more
Sourceimpl PartialEq for CompositeCommand
impl PartialEq for CompositeCommand
Sourceimpl SubCommand for CompositeCommand
impl SubCommand for CompositeCommand
Sourceconst COMMAND: &'static CommandInfo
const COMMAND: &'static CommandInfo
Information about the subcommand.
impl StructuralPartialEq for CompositeCommand